@@ -22,6 +22,8 @@ package php
 import (
 	"io"
 	"os"
+
+	"github.com/pkg/errors"
 )
 
 func shouldSignalBeIgnored(sig os.Signal) bool {
@@ -31,14 +33,14 @@ func shouldSignalBeIgnored(sig os.Signal) bool {
 func symlink(oldname, newname string) error {
 	source, err := os.Open(oldname)
 	if err != nil {
-		return err
+		return errors.WithStack(err)
 	}
 	defer source.Close()
 	destination, err := os.Create(newname)
 	if err != nil {
-		return err
+		return errors.WithStack(err)
 	}
 	defer destination.Close()
 	_, err = io.Copy(destination, source)
-	return err
+	return errors.WithStack(err)
 }
